@@ -57,7 +57,7 @@ import gst
 import hildon
 from portrait import FremantleRotation
 
-version = "0.5 - 2010-08-14"
+version = "0.5-1 - 2010-08-14"
 # Enable/disable debugging
 dbg = 0
 
@@ -80,18 +80,36 @@ class GTK_Main:
     # Where to look for audio files / books
     self.base_media_dir = "/home/user/MyDocs/"
 
-    self.prefs_file = "/home/user/MyDocs/.easyplayer/preferences"
-    self.pl_dirs_file = "/home/user/MyDocs/.easyplayer/playlistdirs"
-    self.pl_files_file = "/home/user/MyDocs/.easyplayer/playlistfiles"
-
+    #self.prefs_file = "/home/user/MyDocs/.easyplayer/preferences"
+    #self.pl_dirs_file = "/home/user/MyDocs/.easyplayer/playlistdirs"
+    #self.pl_files_file = "/home/user/MyDocs/.easyplayer/playlistfiles"
+ 
+    home = os.environ["HOME"] # some people change their user name from "user"
+    self.prefs_file = os.path.join(home, ".easyplayer", "preferences")
+    self.pl_dirs_file = os.path.join(home, ".easyplayer", "playlistdirs")
+    self.pl_files_file = os.path.join(home, ".easyplayer", "playlistfiles")
+ 
     # Try to load the preferences
-    if os.path.isfile(self.prefs_file):
+    #if os.path.isfile(self.prefs_file):
+    #  try:
+    #    fd = open(self.prefs_file)
+    #    self.prefs = pickle.load(fd) # overwrite default values
+    #    fd.close()
+    #  except:
+    #    if (dbg): print "Can't load settings"
+
+
+    try:
+      # doing everything in one function call means we don't have to close
+      # the file
+      self.prefs = pickle.load(open(self.prefs_file))
+    except IOError:
+      self.init_prefs()
+      self.save_prefs()
       try:
-        fd = open(self.prefs_file)
-        self.prefs = pickle.load(fd) # overwrite default values
-        fd.close()
-      except:
-        if (dbg): print "Can't load settings"
+        os.mkdir(os.path.join(home, ".easyplayer"))
+      except OSError:
+        pass
 
     # Look, if the preferences are new enough
     # If not (or some tag "version" just don't exists), overwrite with default
@@ -102,7 +120,6 @@ class GTK_Main:
     except:
       self.init_prefs()
       self.save_prefs()
-
     
     if self.prefs["bigbuttons"] == 1: 
       self.std_size = gtk.HILDON_SIZE_AUTO|gtk.HILDON_SIZE_THUMB_HEIGHT
@@ -123,13 +140,13 @@ class GTK_Main:
     # Try to load the playlist 
     try:
       if (dbg): print "Trying to load dirs..."
-      fd = open(self.pl_dirs_file) 	# Load list containing directories
-      self.pl_dirs = pickle.load(fd) 	# overwrite default values
-      fd.close()
+      # Load list containing directories
+      self.pl_dirs = pickle.load(open(self.pl_dirs_file))
+
       if (dbg): print "Trying to load files..."      
-      fd = open(self.pl_files_file) 	# Load list containng filenames
-      self.pl_files = pickle.load(fd) # overwrite default values
-      fd.close()
+      # Load list containing filenames
+      self.pl_files = pickle.load(open(self.pl_files_file))
+
       self.max_files = len(self.pl_files)	
       if (dbg): print "(load) Max Files:",self.max_files        
     except:
